/****************************************************************************
** Meta object code from reading C++ file 'inputhandleradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "inputhandleradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputhandleradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19InputhandlerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto InputhandlerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19InputhandlerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputhandlerAdaptor",
        "D-Bus Interface",
        "org.kde.plasma.bigscreen.inputhandler",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.plasma.bigscreen.inputhandler\">\n    "
        "<property access=\"readwrite\" type=\"b\" name=\"inputSuppressed\""
        "/>\n    <property access=\"read\" type=\"b\" name=\"inputManuallyS"
        "uppressed\"/>\n    <property access=\"readwrite\" type=\"b\" name="
        "\"autoSuppressInput\"/>\n    <property access=\"readwrite\" type=\""
        "b\" name=\"enabled\"/>\n    <property access=\"readwrite\" type=\""
        "b\" name=\"gameControllerEnabled\"/>\n    <property access=\"readw"
        "rite\" type=\"b\" name=\"cecEnabled\"/>\n    <signal name=\"sdlCon"
        "trollerAdded\">\n      <arg direction=\"out\" type=\"s\" name=\"na"
        "me\"/>\n    </signal>\n    <signal name=\"sdlControllerRemoved\">\n"
        "      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n    </sig"
        "nal>\n    <signal name=\"cecControllerAdded\">\n      <arg directi"
        "on=\"out\" type=\"s\" name=\"name\"/>\n    </signal>\n    <signal "
        "name=\"cecControllerRemoved\">\n      <arg direction=\"out\" type="
        "\"s\" name=\"name\"/>\n    </signal>\n    <signal name=\"inputSupp"
        "ressedChanged\">\n      <arg direction=\"out\" type=\"b\" name=\"s"
        "uppressed\"/>\n      <arg direction=\"out\" type=\"b\" name=\"auto"
        "matic\"/>\n    </signal>\n    <signal name=\"autoSuppressInputChan"
        "ged\">\n      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>"
        "\n    </signal>\n    <signal name=\"homeActionRequested\"/>\n    <"
        "signal name=\"enabledChanged\">\n      <arg direction=\"out\" type"
        "=\"b\" name=\"enabled\"/>\n    </signal>\n    <signal name=\"gameC"
        "ontrollerEnabledChanged\">\n      <arg direction=\"out\" type=\"b\""
        " name=\"enabled\"/>\n    </signal>\n    <signal name=\"cecEnabledC"
        "hanged\">\n      <arg direction=\"out\" type=\"b\" name=\"enabled\""
        "/>\n    </signal>\n    <signal name=\"connectedControllersChanged\""
        "/>\n    <method name=\"isSdlControllerConnected\">\n      <arg dir"
        "ection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"isC"
        "ecControllerConnected\">\n      <arg direction=\"out\" type=\"b\"/"
        ">\n    </method>\n    <method name=\"connectedControllers\">\n    "
        "  <arg direction=\"out\" type=\"av\"/>\n    </method>\n    <method"
        " name=\"setControllerEnabled\">\n      <arg direction=\"in\" type="
        "\"s\" name=\"uniqueIdentifier\"/>\n      <arg direction=\"in\" typ"
        "e=\"b\" name=\"enabled\"/>\n    </method>\n    <method name=\"setS"
        "tartButtonEnabledWhenSuppressed\">\n      <arg direction=\"in\" ty"
        "pe=\"s\" name=\"uniqueIdentifier\"/>\n      <arg direction=\"in\" "
        "type=\"b\" name=\"enabled\"/>\n    </method>\n    <method name=\"s"
        "endStandby\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"logicalAddress\"/>\n    </me"
        "thod>\n    <method name=\"sendImageViewOn\">\n      <arg direction"
        "=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"i\" name"
        "=\"logicalAddress\"/>\n    </method>\n    <method name=\"sendActiv"
        "eSource\">\n      <arg direction=\"out\" type=\"b\"/>\n    </metho"
        "d>\n    <method name=\"queryDevicePowerStatus\">\n      <arg direc"
        "tion=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type=\"i\" "
        "name=\"logicalAddress\"/>\n    </method>\n  </interface>\n",
        "autoSuppressInputChanged",
        "",
        "enabled",
        "cecControllerAdded",
        "name",
        "cecControllerRemoved",
        "cecEnabledChanged",
        "connectedControllersChanged",
        "enabledChanged",
        "gameControllerEnabledChanged",
        "homeActionRequested",
        "inputSuppressedChanged",
        "suppressed",
        "automatic",
        "sdlControllerAdded",
        "sdlControllerRemoved",
        "connectedControllers",
        "QVariantList",
        "isCecControllerConnected",
        "isSdlControllerConnected",
        "queryDevicePowerStatus",
        "logicalAddress",
        "sendActiveSource",
        "sendImageViewOn",
        "sendStandby",
        "setControllerEnabled",
        "uniqueIdentifier",
        "setStartButtonEnabledWhenSuppressed",
        "autoSuppressInput",
        "cecEnabled",
        "gameControllerEnabled",
        "inputManuallySuppressed",
        "inputSuppressed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'autoSuppressInputChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'cecControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'cecControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'cecEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'connectedControllersChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'gameControllerEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'homeActionRequested'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputSuppressedChanged'
        QtMocHelpers::SignalData<void(bool, bool)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Signal 'sdlControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'sdlControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'connectedControllers'
        QtMocHelpers::SlotData<QVariantList()>(21, 6, QMC::AccessPublic, 0x80000000 | 22),
        // Slot 'isCecControllerConnected'
        QtMocHelpers::SlotData<bool()>(23, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isSdlControllerConnected'
        QtMocHelpers::SlotData<bool()>(24, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'queryDevicePowerStatus'
        QtMocHelpers::SlotData<int(int)>(25, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'sendActiveSource'
        QtMocHelpers::SlotData<bool()>(27, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'sendImageViewOn'
        QtMocHelpers::SlotData<bool(int)>(28, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'sendStandby'
        QtMocHelpers::SlotData<bool(int)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setControllerEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'setStartButtonEnabledWhenSuppressed'
        QtMocHelpers::SlotData<void(const QString &, bool)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { QMetaType::Bool, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'autoSuppressInput'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cecEnabled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'gameControllerEnabled'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'inputManuallySuppressed'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'inputSuppressed'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<InputhandlerAdaptor, qt_meta_tag_ZN19InputhandlerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InputhandlerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputhandlerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputhandlerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19InputhandlerAdaptorE_t>.metaTypes,
    nullptr
} };

void InputhandlerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputhandlerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->autoSuppressInputChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->cecControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cecControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->cecEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->connectedControllersChanged(); break;
        case 5: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->gameControllerEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->homeActionRequested(); break;
        case 8: _t->inputSuppressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->sdlControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->sdlControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QVariantList _r = _t->connectedControllers();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isCecControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->isSdlControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->queryDevicePowerStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->sendActiveSource();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->sendImageViewOn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->sendStandby((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setControllerEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->setStartButtonEnabledWhenSuppressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(bool )>(_a, &InputhandlerAdaptor::autoSuppressInputChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(const QString & )>(_a, &InputhandlerAdaptor::cecControllerAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(const QString & )>(_a, &InputhandlerAdaptor::cecControllerRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(bool )>(_a, &InputhandlerAdaptor::cecEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)()>(_a, &InputhandlerAdaptor::connectedControllersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(bool )>(_a, &InputhandlerAdaptor::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(bool )>(_a, &InputhandlerAdaptor::gameControllerEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)()>(_a, &InputhandlerAdaptor::homeActionRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(bool , bool )>(_a, &InputhandlerAdaptor::inputSuppressedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(const QString & )>(_a, &InputhandlerAdaptor::sdlControllerAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputhandlerAdaptor::*)(const QString & )>(_a, &InputhandlerAdaptor::sdlControllerRemoved, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->autoSuppressInput(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->cecEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->gameControllerEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->inputManuallySuppressed(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->inputSuppressed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoSuppressInput(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCecEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setGameControllerEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setInputSuppressed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputhandlerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputhandlerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputhandlerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int InputhandlerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void InputhandlerAdaptor::autoSuppressInputChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void InputhandlerAdaptor::cecControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void InputhandlerAdaptor::cecControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void InputhandlerAdaptor::cecEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void InputhandlerAdaptor::connectedControllersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void InputhandlerAdaptor::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void InputhandlerAdaptor::gameControllerEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void InputhandlerAdaptor::homeActionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void InputhandlerAdaptor::inputSuppressedChanged(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void InputhandlerAdaptor::sdlControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void InputhandlerAdaptor::sdlControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
