/****************************************************************************
** Meta object code from reading C++ file 'bigscreensettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-bigscreen-6.7.4/kcms/bigscreen-settings/bigscreensettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bigscreensettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17BigscreenSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto BigscreenSettings::qt_create_metaobjectdata<qt_meta_tag_ZN17BigscreenSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BigscreenSettings",
        "themeNameChanged",
        "",
        "timeFormatChanged",
        "twentyFourChanged",
        "useNtpChanged",
        "currentTimeChanged",
        "currentDateChanged",
        "load",
        "useColoredTiles",
        "setUseColoredTiles",
        "useWallpaperBlur",
        "setUseWallpaperBlur",
        "saveTimeZone",
        "newtimezone",
        "useNtp",
        "setUseNtp",
        "ntp",
        "currentTime",
        "setCurrentTime",
        "time",
        "currentDate",
        "setCurrentDate",
        "date",
        "saveTime",
        "getShortcut",
        "action",
        "setShortcut",
        "QKeySequence",
        "shortcut",
        "resetShortcut",
        "themeName",
        "globalThemeListModel",
        "GlobalThemeListModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'themeNameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeFormatChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'twentyFourChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useNtpChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTimeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDateChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'useColoredTiles'
        QtMocHelpers::SlotData<bool()>(9, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setUseColoredTiles'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'useWallpaperBlur'
        QtMocHelpers::SlotData<bool()>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setUseWallpaperBlur'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'saveTimeZone'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'useNtp'
        QtMocHelpers::SlotData<bool()>(15, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setUseNtp'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'currentTime'
        QtMocHelpers::SlotData<QTime()>(18, 2, QMC::AccessPublic, QMetaType::QTime),
        // Slot 'setCurrentTime'
        QtMocHelpers::SlotData<void(const QTime &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 20 },
        }}),
        // Slot 'currentDate'
        QtMocHelpers::SlotData<QDate()>(21, 2, QMC::AccessPublic, QMetaType::QDate),
        // Slot 'setCurrentDate'
        QtMocHelpers::SlotData<void(const QDate &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 23 },
        }}),
        // Slot 'saveTime'
        QtMocHelpers::SlotData<bool()>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'getShortcut'
        QtMocHelpers::SlotData<QString(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'setShortcut'
        QtMocHelpers::SlotData<bool(const QString &, const QKeySequence &)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 26 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'resetShortcut'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'themeName'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'globalThemeListModel'
        QtMocHelpers::PropertyData<GlobalThemeListModel*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'currentTime'
        QtMocHelpers::PropertyData<QTime>(18, QMetaType::QTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'currentDate'
        QtMocHelpers::PropertyData<QDate>(21, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'useNtp'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BigscreenSettings, qt_meta_tag_ZN17BigscreenSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BigscreenSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BigscreenSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BigscreenSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17BigscreenSettingsE_t>.metaTypes,
    nullptr
} };

void BigscreenSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BigscreenSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->themeNameChanged(); break;
        case 1: _t->timeFormatChanged(); break;
        case 2: _t->twentyFourChanged(); break;
        case 3: _t->useNtpChanged(); break;
        case 4: _t->currentTimeChanged(); break;
        case 5: _t->currentDateChanged(); break;
        case 6: _t->load(); break;
        case 7: { bool _r = _t->useColoredTiles();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setUseColoredTiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: { bool _r = _t->useWallpaperBlur();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setUseWallpaperBlur((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->saveTimeZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { bool _r = _t->useNtp();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setUseNtp((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: { QTime _r = _t->currentTime();
            if (_a[0]) *reinterpret_cast<QTime*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setCurrentTime((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 16: { QDate _r = _t->currentDate();
            if (_a[0]) *reinterpret_cast<QDate*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setCurrentDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 18: { bool _r = _t->saveTime();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->getShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->setShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->resetShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::themeNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::timeFormatChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::twentyFourChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::useNtpChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::currentTimeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigscreenSettings::*)()>(_a, &BigscreenSettings::currentDateChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->themeName(); break;
        case 1: *reinterpret_cast<GlobalThemeListModel**>(_v) = _t->globalThemeListModel(); break;
        case 2: *reinterpret_cast<QTime*>(_v) = _t->currentTime(); break;
        case 3: *reinterpret_cast<QDate*>(_v) = _t->currentDate(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->useNtp(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCurrentTime(*reinterpret_cast<QTime*>(_v)); break;
        case 3: _t->setCurrentDate(*reinterpret_cast<QDate*>(_v)); break;
        case 4: _t->setUseNtp(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BigscreenSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BigscreenSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BigscreenSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KQuickConfigModule::qt_metacast(_clname);
}

int BigscreenSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void BigscreenSettings::themeNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BigscreenSettings::timeFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BigscreenSettings::twentyFourChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BigscreenSettings::useNtpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BigscreenSettings::currentTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BigscreenSettings::currentDateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
