/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<browsermanager.h>)
#  include <browsermanager.h>
#endif
#if __has_include(<useragent.h>)
#  include <useragent.h>
#endif
#if __has_include(<webprofile.h>)
#  include <webprofile.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_bigscreen_webapp()
{
    qmlRegisterModule("org.kde.bigscreen.webapp", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BrowserManager>("org.kde.bigscreen.webapp", 254);
    qmlRegisterTypesAndRevisions<UserAgent>("org.kde.bigscreen.webapp", 254);
    qmlRegisterTypesAndRevisions<WebProfile>("org.kde.bigscreen.webapp", 254);
    qmlRegisterAnonymousType<QQuickWebEngineProfile, 254>("org.kde.bigscreen.webapp", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.bigscreen.webapp", 254, 254);
}

static const QQmlModuleRegistration orgkdebigscreenwebappRegistration("org.kde.bigscreen.webapp", qml_register_types_org_kde_bigscreen_webapp);
