/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.biglauncher.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BIGLAUNCHERINTERFACE_H
#define BIGLAUNCHERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.biglauncher
 */
class OrgKdeBiglauncherInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.biglauncher"; }

public:
    OrgKdeBiglauncherInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeBiglauncherInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> activateSettingsShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activateSettingsShortcut"), argumentList);
    }

    inline QDBusPendingReply<QString> activateTasksShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activateTasksShortcut"), argumentList);
    }

    inline QDBusPendingReply<> activateWallpaperSelector()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activateWallpaperSelector"), argumentList);
    }

    inline QDBusPendingReply<bool> coloredTilesActive()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("coloredTilesActive"), argumentList);
    }

    inline QDBusPendingReply<QString> displayHomeOverlayShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("displayHomeOverlayShortcut"), argumentList);
    }

    inline QDBusPendingReply<QString> displayHomeScreenShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("displayHomeScreenShortcut"), argumentList);
    }

    inline QDBusPendingReply<> resetActivateSettingsShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetActivateSettingsShortcut"), argumentList);
    }

    inline QDBusPendingReply<> resetActivateTasksShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetActivateTasksShortcut"), argumentList);
    }

    inline QDBusPendingReply<> resetDisplayHomeOverlayShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetDisplayHomeOverlayShortcut"), argumentList);
    }

    inline QDBusPendingReply<> resetDisplayHomeScreenShortcut()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("resetDisplayHomeScreenShortcut"), argumentList);
    }

    inline QDBusPendingReply<bool> setActivateSettingsShortcut(const QString &shortcut)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(shortcut);
        return asyncCallWithArgumentList(QStringLiteral("setActivateSettingsShortcut"), argumentList);
    }

    inline QDBusPendingReply<bool> setActivateTasksShortcut(const QString &shortcut)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(shortcut);
        return asyncCallWithArgumentList(QStringLiteral("setActivateTasksShortcut"), argumentList);
    }

    inline QDBusPendingReply<bool> setDisplayHomeOverlayShortcut(const QString &shortcut)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(shortcut);
        return asyncCallWithArgumentList(QStringLiteral("setDisplayHomeOverlayShortcut"), argumentList);
    }

    inline QDBusPendingReply<bool> setDisplayHomeScreenShortcut(const QString &shortcut)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(shortcut);
        return asyncCallWithArgumentList(QStringLiteral("setDisplayHomeScreenShortcut"), argumentList);
    }

    inline QDBusPendingReply<> useColoredTiles(bool coloredTiles)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(coloredTiles);
        return asyncCallWithArgumentList(QStringLiteral("useColoredTiles"), argumentList);
    }

    inline QDBusPendingReply<> useWallpaperBlur(bool wallpaperBlur)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(wallpaperBlur);
        return asyncCallWithArgumentList(QStringLiteral("useWallpaperBlur"), argumentList);
    }

    inline QDBusPendingReply<bool> wallpaperBlurActive()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("wallpaperBlurActive"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void useColoredTilesChanged(bool msgUseColoredTiles);
    void useWallpaperBlurChanged(bool msgUseWallpaperBlur);
};

namespace org {
  namespace kde {
    using biglauncher = ::OrgKdeBiglauncherInterface;
  }
}

#endif
