/****************************************************************************
** Meta object code from reading C++ file 'inputhandlerinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "inputhandlerinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputhandlerinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdePlasmaBigscreenInputhandlerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdePlasmaBigscreenInputhandlerInterface",
        "autoSuppressInputChanged",
        "",
        "enabled",
        "cecControllerAdded",
        "name",
        "cecControllerRemoved",
        "cecEnabledChanged",
        "connectedControllersChanged",
        "enabledChanged",
        "gameControllerEnabledChanged",
        "homeActionRequested",
        "inputSuppressedChanged",
        "suppressed",
        "automatic",
        "sdlControllerAdded",
        "sdlControllerRemoved",
        "connectedControllers",
        "QDBusPendingReply<QVariantList>",
        "isCecControllerConnected",
        "QDBusPendingReply<bool>",
        "isSdlControllerConnected",
        "queryDevicePowerStatus",
        "QDBusPendingReply<int>",
        "logicalAddress",
        "sendActiveSource",
        "sendImageViewOn",
        "sendStandby",
        "setControllerEnabled",
        "QDBusPendingReply<>",
        "uniqueIdentifier",
        "setStartButtonEnabledWhenSuppressed",
        "autoSuppressInput",
        "cecEnabled",
        "gameControllerEnabled",
        "inputManuallySuppressed",
        "inputSuppressed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'autoSuppressInputChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'cecControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cecControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cecEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'connectedControllersChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'gameControllerEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'homeActionRequested'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputSuppressedChanged'
        QtMocHelpers::SignalData<void(bool, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'sdlControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'sdlControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'connectedControllers'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantList>()>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'isCecControllerConnected'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'isSdlControllerConnected'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(21, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'queryDevicePowerStatus'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int)>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'sendActiveSource'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(25, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'sendImageViewOn'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int)>(26, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'sendStandby'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int)>(27, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setControllerEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(28, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 30 }, { QMetaType::Bool, 3 },
        }}),
        // Slot 'setStartButtonEnabledWhenSuppressed'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(31, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 30 }, { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'autoSuppressInput'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cecEnabled'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'gameControllerEnabled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'inputManuallySuppressed'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'inputSuppressed'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdePlasmaBigscreenInputhandlerInterface, qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdePlasmaBigscreenInputhandlerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdePlasmaBigscreenInputhandlerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdePlasmaBigscreenInputhandlerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->autoSuppressInputChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->cecControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cecControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->cecEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->connectedControllersChanged(); break;
        case 5: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->gameControllerEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->homeActionRequested(); break;
        case 8: _t->inputSuppressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->sdlControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->sdlControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QDBusPendingReply<QVariantList> _r = _t->connectedControllers();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantList>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->isCecControllerConnected();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->isSdlControllerConnected();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<int> _r = _t->queryDevicePowerStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool> _r = _t->sendActiveSource();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->sendImageViewOn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<bool> _r = _t->sendStandby((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setControllerEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setStartButtonEnabledWhenSuppressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(bool )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::autoSuppressInputChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(const QString & )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::cecControllerAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(const QString & )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::cecControllerRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(bool )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::cecEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)()>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::connectedControllersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(bool )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(bool )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::gameControllerEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)()>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::homeActionRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(bool , bool )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::inputSuppressedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(const QString & )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::sdlControllerAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdePlasmaBigscreenInputhandlerInterface::*)(const QString & )>(_a, &OrgKdePlasmaBigscreenInputhandlerInterface::sdlControllerRemoved, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->autoSuppressInput(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->cecEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->gameControllerEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->inputManuallySuppressed(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->inputSuppressed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutoSuppressInput(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setCecEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setGameControllerEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setInputSuppressed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdePlasmaBigscreenInputhandlerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdePlasmaBigscreenInputhandlerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgKdePlasmaBigscreenInputhandlerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdePlasmaBigscreenInputhandlerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void OrgKdePlasmaBigscreenInputhandlerInterface::autoSuppressInputChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgKdePlasmaBigscreenInputhandlerInterface::cecControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgKdePlasmaBigscreenInputhandlerInterface::cecControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgKdePlasmaBigscreenInputhandlerInterface::cecEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgKdePlasmaBigscreenInputhandlerInterface::connectedControllersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OrgKdePlasmaBigscreenInputhandlerInterface::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgKdePlasmaBigscreenInputhandlerInterface::gameControllerEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OrgKdePlasmaBigscreenInputhandlerInterface::homeActionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void OrgKdePlasmaBigscreenInputhandlerInterface::inputSuppressedChanged(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void OrgKdePlasmaBigscreenInputhandlerInterface::sdlControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void OrgKdePlasmaBigscreenInputhandlerInterface::sdlControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
