/****************************************************************************
** Meta object code from reading C++ file 'controllerhandlerstatus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-bigscreen-6.7.4/components/controllerhandler/controllerhandlerstatus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'controllerhandlerstatus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ControllerHandlerStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto ControllerHandlerStatus::qt_create_metaobjectdata<qt_meta_tag_ZN23ControllerHandlerStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ControllerHandlerStatus",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "sdlControllerConnectedChanged",
        "",
        "cecControllerConnectedChanged",
        "serviceAvailableChanged",
        "inputSuppressedChanged",
        "suppressed",
        "automatic",
        "enabledChanged",
        "gameControllerEnabledChanged",
        "sdlControllerAdded",
        "name",
        "sdlControllerRemoved",
        "cecControllerAdded",
        "cecControllerRemoved",
        "homeActionRequested",
        "connectToService",
        "disconnectFromService",
        "onSdlControllerAdded",
        "onSdlControllerRemoved",
        "onCecControllerAdded",
        "onCecControllerRemoved",
        "onInputSuppressedChanged",
        "onEnabledChanged",
        "enabled",
        "onGameControllerEnabledChanged",
        "isSdlControllerConnected",
        "isCecControllerConnected",
        "sdlControllerConnected",
        "cecControllerConnected",
        "serviceAvailable",
        "inputSuppressed",
        "inputManuallySuppressed",
        "gameControllerEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sdlControllerConnectedChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cecControllerConnectedChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serviceAvailableChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputSuppressedChanged'
        QtMocHelpers::SignalData<void(bool, bool)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gameControllerEnabledChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdlControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'sdlControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'cecControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'cecControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'homeActionRequested'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'connectToService'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'disconnectFromService'
        QtMocHelpers::SlotData<void()>(21, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSdlControllerAdded'
        QtMocHelpers::SlotData<void(const QString &)>(22, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onSdlControllerRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(23, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onCecControllerAdded'
        QtMocHelpers::SlotData<void(const QString &)>(24, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onCecControllerRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(25, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onInputSuppressedChanged'
        QtMocHelpers::SlotData<void(bool, bool)>(26, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Slot 'onEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'onGameControllerEnabledChanged'
        QtMocHelpers::SlotData<void(bool)>(29, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Method 'isSdlControllerConnected'
        QtMocHelpers::MethodData<bool()>(30, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isCecControllerConnected'
        QtMocHelpers::MethodData<bool()>(31, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sdlControllerConnected'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'cecControllerConnected'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'serviceAvailable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'inputSuppressed'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'inputManuallySuppressed'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'gameControllerEnabled'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ControllerHandlerStatus, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ControllerHandlerStatus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ControllerHandlerStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ControllerHandlerStatusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ControllerHandlerStatusE_t>.metaTypes,
    nullptr
} };

void ControllerHandlerStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ControllerHandlerStatus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sdlControllerConnectedChanged(); break;
        case 1: _t->cecControllerConnectedChanged(); break;
        case 2: _t->serviceAvailableChanged(); break;
        case 3: _t->inputSuppressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->enabledChanged(); break;
        case 5: _t->gameControllerEnabledChanged(); break;
        case 6: _t->sdlControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->sdlControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->cecControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->cecControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->homeActionRequested(); break;
        case 11: _t->connectToService(); break;
        case 12: _t->disconnectFromService(); break;
        case 13: _t->onSdlControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->onSdlControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->onCecControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->onCecControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->onInputSuppressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 18: _t->onEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->onGameControllerEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: { bool _r = _t->isSdlControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isCecControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::sdlControllerConnectedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::cecControllerConnectedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::serviceAvailableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)(bool , bool )>(_a, &ControllerHandlerStatus::inputSuppressedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::enabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::gameControllerEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)(const QString & )>(_a, &ControllerHandlerStatus::sdlControllerAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)(const QString & )>(_a, &ControllerHandlerStatus::sdlControllerRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)(const QString & )>(_a, &ControllerHandlerStatus::cecControllerAdded, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)(const QString & )>(_a, &ControllerHandlerStatus::cecControllerRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ControllerHandlerStatus::*)()>(_a, &ControllerHandlerStatus::homeActionRequested, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->sdlControllerConnected(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->cecControllerConnected(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->serviceAvailable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->inputSuppressed(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->inputManuallySuppressed(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->gameControllerEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setInputSuppressed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ControllerHandlerStatus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ControllerHandlerStatus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ControllerHandlerStatusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ControllerHandlerStatus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ControllerHandlerStatus::sdlControllerConnectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ControllerHandlerStatus::cecControllerConnectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ControllerHandlerStatus::serviceAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ControllerHandlerStatus::inputSuppressedChanged(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ControllerHandlerStatus::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ControllerHandlerStatus::gameControllerEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ControllerHandlerStatus::sdlControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ControllerHandlerStatus::sdlControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ControllerHandlerStatus::cecControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ControllerHandlerStatus::cecControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ControllerHandlerStatus::homeActionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
