/****************************************************************************
** Meta object code from reading C++ file 'biglauncheradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "biglauncheradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'biglauncheradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18BiglauncherAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto BiglauncherAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18BiglauncherAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BiglauncherAdaptor",
        "D-Bus Interface",
        "org.kde.biglauncher",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.biglauncher\">\n    <signal name=\"use"
        "ColoredTilesChanged\">\n      <arg direction=\"out\" type=\"b\" na"
        "me=\"msgUseColoredTiles\"/>\n    </signal>\n    <signal name=\"use"
        "WallpaperBlurChanged\">\n      <arg direction=\"out\" type=\"b\" n"
        "ame=\"msgUseWallpaperBlur\"/>\n    </signal>\n    <method name=\"u"
        "seColoredTiles\">\n      <arg direction=\"in\" type=\"b\" name=\"c"
        "oloredTiles\"/>\n    </method>\n    <method name=\"coloredTilesAct"
        "ive\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"useWallpaperBlur\">\n      <arg direction=\"in\""
        " type=\"b\" name=\"wallpaperBlur\"/>\n    </method>\n    <method n"
        "ame=\"wallpaperBlurActive\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"activateWallpaperSelector"
        "\"/>\n    <method name=\"activateSettingsShortcut\">\n      <arg d"
        "irection=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"a"
        "ctivateTasksShortcut\">\n      <arg direction=\"out\" type=\"s\"/>"
        "\n    </method>\n    <method name=\"displayHomeScreenShortcut\">\n"
        "      <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <met"
        "hod name=\"displayHomeOverlayShortcut\">\n      <arg direction=\"o"
        "ut\" type=\"s\"/>\n    </method>\n    <method name=\"setActivateSe"
        "ttingsShortcut\">\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n    </meth"
        "od>\n    <method name=\"setActivateTasksShortcut\">\n      <arg di"
        "rection=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"shortcut\"/>\n    </method>\n    <method name=\"setDispl"
        "ayHomeScreenShortcut\">\n      <arg direction=\"out\" type=\"b\"/>"
        "\n      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n    "
        "</method>\n    <method name=\"setDisplayHomeOverlayShortcut\">\n  "
        "    <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"shortcut\"/>\n    </method>\n    <method name"
        "=\"resetActivateSettingsShortcut\"/>\n    <method name=\"resetActi"
        "vateTasksShortcut\"/>\n    <method name=\"resetDisplayHomeScreenSh"
        "ortcut\"/>\n    <method name=\"resetDisplayHomeOverlayShortcut\"/>"
        "\n  </interface>\n",
        "useColoredTilesChanged",
        "",
        "msgUseColoredTiles",
        "useWallpaperBlurChanged",
        "msgUseWallpaperBlur",
        "activateSettingsShortcut",
        "activateTasksShortcut",
        "activateWallpaperSelector",
        "coloredTilesActive",
        "displayHomeOverlayShortcut",
        "displayHomeScreenShortcut",
        "resetActivateSettingsShortcut",
        "resetActivateTasksShortcut",
        "resetDisplayHomeOverlayShortcut",
        "resetDisplayHomeScreenShortcut",
        "setActivateSettingsShortcut",
        "shortcut",
        "setActivateTasksShortcut",
        "setDisplayHomeOverlayShortcut",
        "setDisplayHomeScreenShortcut",
        "useColoredTiles",
        "coloredTiles",
        "useWallpaperBlur",
        "wallpaperBlur",
        "wallpaperBlurActive"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'useColoredTilesChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'useWallpaperBlurChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'activateSettingsShortcut'
        QtMocHelpers::SlotData<QString()>(10, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'activateTasksShortcut'
        QtMocHelpers::SlotData<QString()>(11, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'activateWallpaperSelector'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'coloredTilesActive'
        QtMocHelpers::SlotData<bool()>(13, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'displayHomeOverlayShortcut'
        QtMocHelpers::SlotData<QString()>(14, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'displayHomeScreenShortcut'
        QtMocHelpers::SlotData<QString()>(15, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'resetActivateSettingsShortcut'
        QtMocHelpers::SlotData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetActivateTasksShortcut'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setActivateSettingsShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setActivateTasksShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'useColoredTiles'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'useWallpaperBlur'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'wallpaperBlurActive'
        QtMocHelpers::SlotData<bool()>(29, 6, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BiglauncherAdaptor, qt_meta_tag_ZN18BiglauncherAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BiglauncherAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BiglauncherAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BiglauncherAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18BiglauncherAdaptorE_t>.metaTypes,
    nullptr
} };

void BiglauncherAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BiglauncherAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->useColoredTilesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->useWallpaperBlurChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: { QString _r = _t->activateSettingsShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->activateTasksShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->activateWallpaperSelector(); break;
        case 5: { bool _r = _t->coloredTilesActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->displayHomeOverlayShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->displayHomeScreenShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->resetActivateSettingsShortcut(); break;
        case 9: _t->resetActivateTasksShortcut(); break;
        case 10: _t->resetDisplayHomeOverlayShortcut(); break;
        case 11: _t->resetDisplayHomeScreenShortcut(); break;
        case 12: { bool _r = _t->setActivateSettingsShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setActivateTasksShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->setDisplayHomeOverlayShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->setDisplayHomeScreenShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->useColoredTiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->useWallpaperBlur((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: { bool _r = _t->wallpaperBlurActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BiglauncherAdaptor::*)(bool )>(_a, &BiglauncherAdaptor::useColoredTilesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BiglauncherAdaptor::*)(bool )>(_a, &BiglauncherAdaptor::useWallpaperBlurChanged, 1))
            return;
    }
}

const QMetaObject *BiglauncherAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BiglauncherAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BiglauncherAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int BiglauncherAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void BiglauncherAdaptor::useColoredTilesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BiglauncherAdaptor::useWallpaperBlurChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
