/****************************************************************************
** Meta object code from reading C++ file 'inputhandlerdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../plasma-bigscreen-6.7.4/inputhandler/inputhandlerdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputhandlerdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16InputHandlerDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto InputHandlerDBus::qt_create_metaobjectdata<qt_meta_tag_ZN16InputHandlerDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputHandlerDBus",
        "D-Bus Interface",
        "org.kde.plasma.bigscreen.inputhandler",
        "sdlControllerAdded",
        "",
        "name",
        "sdlControllerRemoved",
        "cecControllerAdded",
        "cecControllerRemoved",
        "inputSuppressedChanged",
        "suppressed",
        "automatic",
        "autoSuppressInputChanged",
        "enabled",
        "homeActionRequested",
        "enabledChanged",
        "gameControllerEnabledChanged",
        "cecEnabledChanged",
        "connectedControllersChanged",
        "isSdlControllerConnected",
        "isCecControllerConnected",
        "connectedControllers",
        "QVariantList",
        "setControllerEnabled",
        "uniqueIdentifier",
        "setStartButtonEnabledWhenSuppressed",
        "sendStandby",
        "logicalAddress",
        "sendImageViewOn",
        "sendActiveSource",
        "queryDevicePowerStatus",
        "inputSuppressed",
        "inputManuallySuppressed",
        "autoSuppressInput",
        "gameControllerEnabled",
        "cecEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sdlControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'sdlControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cecControllerAdded'
        QtMocHelpers::SignalData<void(const QString &)>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'cecControllerRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'inputSuppressedChanged'
        QtMocHelpers::SignalData<void(bool, bool)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'autoSuppressInputChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'homeActionRequested'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'gameControllerEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'cecEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'connectedControllersChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'isSdlControllerConnected'
        QtMocHelpers::SlotData<bool() const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'isCecControllerConnected'
        QtMocHelpers::SlotData<bool() const>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'connectedControllers'
        QtMocHelpers::SlotData<QVariantList() const>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 22),
        // Slot 'setControllerEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'setStartButtonEnabledWhenSuppressed'
        QtMocHelpers::SlotData<void(const QString &, bool)>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'sendStandby'
        QtMocHelpers::SlotData<bool(int)>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'sendImageViewOn'
        QtMocHelpers::SlotData<bool(int)>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'sendActiveSource'
        QtMocHelpers::SlotData<bool()>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'queryDevicePowerStatus'
        QtMocHelpers::SlotData<int(int)>(30, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inputSuppressed'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'inputManuallySuppressed'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'autoSuppressInput'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'gameControllerEnabled'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'cecEnabled'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<InputHandlerDBus, qt_meta_tag_ZN16InputHandlerDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InputHandlerDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16InputHandlerDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16InputHandlerDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16InputHandlerDBusE_t>.metaTypes,
    nullptr
} };

void InputHandlerDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputHandlerDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sdlControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->sdlControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->cecControllerAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->cecControllerRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->inputSuppressedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->autoSuppressInputChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->homeActionRequested(); break;
        case 7: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->gameControllerEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->cecEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->connectedControllersChanged(); break;
        case 11: { bool _r = _t->isSdlControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isCecControllerConnected();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantList _r = _t->connectedControllers();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setControllerEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->setStartButtonEnabledWhenSuppressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 16: { bool _r = _t->sendStandby((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->sendImageViewOn((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->sendActiveSource();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { int _r = _t->queryDevicePowerStatus((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(const QString & )>(_a, &InputHandlerDBus::sdlControllerAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(const QString & )>(_a, &InputHandlerDBus::sdlControllerRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(const QString & )>(_a, &InputHandlerDBus::cecControllerAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(const QString & )>(_a, &InputHandlerDBus::cecControllerRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(bool , bool )>(_a, &InputHandlerDBus::inputSuppressedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(bool )>(_a, &InputHandlerDBus::autoSuppressInputChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)()>(_a, &InputHandlerDBus::homeActionRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(bool )>(_a, &InputHandlerDBus::enabledChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(bool )>(_a, &InputHandlerDBus::gameControllerEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)(bool )>(_a, &InputHandlerDBus::cecEnabledChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerDBus::*)()>(_a, &InputHandlerDBus::connectedControllersChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isInputSuppressed(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isInputManuallySuppressed(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->autoSuppressInput(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isGameControllerEnabled(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isCecEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInputSuppressed(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setAutoSuppressInput(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setGameControllerEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCecEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputHandlerDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputHandlerDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16InputHandlerDBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputHandlerDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void InputHandlerDBus::sdlControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void InputHandlerDBus::sdlControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void InputHandlerDBus::cecControllerAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void InputHandlerDBus::cecControllerRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void InputHandlerDBus::inputSuppressedChanged(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void InputHandlerDBus::autoSuppressInputChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void InputHandlerDBus::homeActionRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void InputHandlerDBus::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void InputHandlerDBus::gameControllerEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void InputHandlerDBus::cecEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void InputHandlerDBus::connectedControllersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
