/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasma.bigscreen.inputhandler.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "inputhandleradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class InputhandlerAdaptor
 */

InputhandlerAdaptor::InputhandlerAdaptor(InputHandlerDBus *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

InputhandlerAdaptor::~InputhandlerAdaptor()
{
    // destructor
}

bool InputhandlerAdaptor::autoSuppressInput() const
{
    // get the value of property autoSuppressInput
    return qvariant_cast< bool >(parent()->property("autoSuppressInput"));
}

void InputhandlerAdaptor::setAutoSuppressInput(bool value)
{
    // set the value of property autoSuppressInput
    parent()->setProperty("autoSuppressInput", QVariant::fromValue(value));
}

bool InputhandlerAdaptor::cecEnabled() const
{
    // get the value of property cecEnabled
    return qvariant_cast< bool >(parent()->property("cecEnabled"));
}

void InputhandlerAdaptor::setCecEnabled(bool value)
{
    // set the value of property cecEnabled
    parent()->setProperty("cecEnabled", QVariant::fromValue(value));
}

bool InputhandlerAdaptor::enabled() const
{
    // get the value of property enabled
    return qvariant_cast< bool >(parent()->property("enabled"));
}

void InputhandlerAdaptor::setEnabled(bool value)
{
    // set the value of property enabled
    parent()->setProperty("enabled", QVariant::fromValue(value));
}

bool InputhandlerAdaptor::gameControllerEnabled() const
{
    // get the value of property gameControllerEnabled
    return qvariant_cast< bool >(parent()->property("gameControllerEnabled"));
}

void InputhandlerAdaptor::setGameControllerEnabled(bool value)
{
    // set the value of property gameControllerEnabled
    parent()->setProperty("gameControllerEnabled", QVariant::fromValue(value));
}

bool InputhandlerAdaptor::inputManuallySuppressed() const
{
    // get the value of property inputManuallySuppressed
    return qvariant_cast< bool >(parent()->property("inputManuallySuppressed"));
}

bool InputhandlerAdaptor::inputSuppressed() const
{
    // get the value of property inputSuppressed
    return qvariant_cast< bool >(parent()->property("inputSuppressed"));
}

void InputhandlerAdaptor::setInputSuppressed(bool value)
{
    // set the value of property inputSuppressed
    parent()->setProperty("inputSuppressed", QVariant::fromValue(value));
}

QVariantList InputhandlerAdaptor::connectedControllers()
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.connectedControllers
    return parent()->connectedControllers();
}

bool InputhandlerAdaptor::isCecControllerConnected()
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.isCecControllerConnected
    return parent()->isCecControllerConnected();
}

bool InputhandlerAdaptor::isSdlControllerConnected()
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.isSdlControllerConnected
    return parent()->isSdlControllerConnected();
}

int InputhandlerAdaptor::queryDevicePowerStatus(int logicalAddress)
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.queryDevicePowerStatus
    return parent()->queryDevicePowerStatus(logicalAddress);
}

bool InputhandlerAdaptor::sendActiveSource()
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.sendActiveSource
    return parent()->sendActiveSource();
}

bool InputhandlerAdaptor::sendImageViewOn(int logicalAddress)
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.sendImageViewOn
    return parent()->sendImageViewOn(logicalAddress);
}

bool InputhandlerAdaptor::sendStandby(int logicalAddress)
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.sendStandby
    return parent()->sendStandby(logicalAddress);
}

void InputhandlerAdaptor::setControllerEnabled(const QString &uniqueIdentifier, bool enabled)
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.setControllerEnabled
    parent()->setControllerEnabled(uniqueIdentifier, enabled);
}

void InputhandlerAdaptor::setStartButtonEnabledWhenSuppressed(const QString &uniqueIdentifier, bool enabled)
{
    // handle method call org.kde.plasma.bigscreen.inputhandler.setStartButtonEnabledWhenSuppressed
    parent()->setStartButtonEnabledWhenSuppressed(uniqueIdentifier, enabled);
}


#include "moc_inputhandleradaptor.cpp"
