/****************************************************************************
** Meta object code from reading C++ file 'biglauncherinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "biglauncherinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'biglauncherinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeBiglauncherInterface::qt_create_metaobjectdata<qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeBiglauncherInterface",
        "useColoredTilesChanged",
        "",
        "msgUseColoredTiles",
        "useWallpaperBlurChanged",
        "msgUseWallpaperBlur",
        "activateSettingsShortcut",
        "QDBusPendingReply<QString>",
        "activateTasksShortcut",
        "activateWallpaperSelector",
        "QDBusPendingReply<>",
        "coloredTilesActive",
        "QDBusPendingReply<bool>",
        "displayHomeOverlayShortcut",
        "displayHomeScreenShortcut",
        "resetActivateSettingsShortcut",
        "resetActivateTasksShortcut",
        "resetDisplayHomeOverlayShortcut",
        "resetDisplayHomeScreenShortcut",
        "setActivateSettingsShortcut",
        "shortcut",
        "setActivateTasksShortcut",
        "setDisplayHomeOverlayShortcut",
        "setDisplayHomeScreenShortcut",
        "useColoredTiles",
        "coloredTiles",
        "useWallpaperBlur",
        "wallpaperBlur",
        "wallpaperBlurActive"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'useColoredTilesChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'useWallpaperBlurChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'activateSettingsShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(6, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'activateTasksShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(8, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'activateWallpaperSelector'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'coloredTilesActive'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(11, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'displayHomeOverlayShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(13, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'displayHomeScreenShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(14, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'resetActivateSettingsShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'resetActivateTasksShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(16, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'resetDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(17, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'resetDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(18, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'setActivateSettingsShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'setActivateTasksShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'setDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'setDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'useColoredTiles'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'useWallpaperBlur'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(26, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'wallpaperBlurActive'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(28, 2, QMC::AccessPublic, 0x80000000 | 12),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeBiglauncherInterface, qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeBiglauncherInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeBiglauncherInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeBiglauncherInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->useColoredTilesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->useWallpaperBlurChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: { QDBusPendingReply<QString> _r = _t->activateSettingsShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->activateTasksShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->activateWallpaperSelector();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->coloredTilesActive();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QString> _r = _t->displayHomeOverlayShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QString> _r = _t->displayHomeScreenShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->resetActivateSettingsShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->resetActivateTasksShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->resetDisplayHomeOverlayShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->resetDisplayHomeScreenShortcut();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->setActivateSettingsShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<bool> _r = _t->setActivateTasksShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<bool> _r = _t->setDisplayHomeOverlayShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool> _r = _t->setDisplayHomeScreenShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->useColoredTiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->useWallpaperBlur((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<bool> _r = _t->wallpaperBlurActive();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeBiglauncherInterface::*)(bool )>(_a, &OrgKdeBiglauncherInterface::useColoredTilesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeBiglauncherInterface::*)(bool )>(_a, &OrgKdeBiglauncherInterface::useWallpaperBlurChanged, 1))
            return;
    }
}

const QMetaObject *OrgKdeBiglauncherInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeBiglauncherInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26OrgKdeBiglauncherInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeBiglauncherInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeBiglauncherInterface::useColoredTilesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgKdeBiglauncherInterface::useWallpaperBlurChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
