/****************************************************************************
** Meta object code from reading C++ file 'inputhandlersettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../inputhandlersettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputhandlersettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20InputHandlerSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto InputHandlerSettings::qt_create_metaobjectdata<qt_meta_tag_ZN20InputHandlerSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputHandlerSettings",
        "enabledChanged",
        "",
        "gameControllerEnabledChanged",
        "cecEnabledChanged",
        "autoSuppressInputChanged",
        "disabledControllersChanged",
        "startButtonDisabledWhenSuppressedControllersChanged",
        "enabled",
        "isEnabledImmutable",
        "defaultEnabledValue",
        "gameControllerEnabled",
        "isGameControllerEnabledImmutable",
        "defaultGameControllerEnabledValue",
        "cecEnabled",
        "isCecEnabledImmutable",
        "defaultCecEnabledValue",
        "autoSuppressInput",
        "isAutoSuppressInputImmutable",
        "defaultAutoSuppressInputValue",
        "disabledControllers",
        "isDisabledControllersImmutable",
        "startButtonDisabledWhenSuppressedControllers",
        "isStartButtonDisabledWhenSuppressedControllersImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gameControllerEnabledChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cecEnabledChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoSuppressInputChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disabledControllersChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startButtonDisabledWhenSuppressedControllersChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnabledValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gameControllerEnabled'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isGameControllerEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGameControllerEnabledValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cecEnabled'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isCecEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCecEnabledValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoSuppressInput'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isAutoSuppressInputImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoSuppressInputValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disabledControllers'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDisabledControllersImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'startButtonDisabledWhenSuppressedControllers'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isStartButtonDisabledWhenSuppressedControllersImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InputHandlerSettings, qt_meta_tag_ZN20InputHandlerSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputHandlerSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KCoreConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20InputHandlerSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20InputHandlerSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20InputHandlerSettingsE_t>.metaTypes,
    nullptr
} };

void InputHandlerSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputHandlerSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged(); break;
        case 1: _t->gameControllerEnabledChanged(); break;
        case 2: _t->cecEnabledChanged(); break;
        case 3: _t->autoSuppressInputChanged(); break;
        case 4: _t->disabledControllersChanged(); break;
        case 5: _t->startButtonDisabledWhenSuppressedControllersChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::gameControllerEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::cecEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::autoSuppressInputChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::disabledControllersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputHandlerSettings::*)()>(_a, &InputHandlerSettings::startButtonDisabledWhenSuppressedControllersChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEnabledImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultEnabledValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->gameControllerEnabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isGameControllerEnabledImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultGameControllerEnabledValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->cecEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isCecEnabledImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultCecEnabledValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->autoSuppressInput(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAutoSuppressInputImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultAutoSuppressInputValue(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->disabledControllers(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDisabledControllersImmutable(); break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->startButtonDisabledWhenSuppressedControllers(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isStartButtonDisabledWhenSuppressedControllersImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setGameControllerEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCecEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setAutoSuppressInput(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setDisabledControllers(*reinterpret_cast<QStringList*>(_v)); break;
        case 14: _t->setStartButtonDisabledWhenSuppressedControllers(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputHandlerSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputHandlerSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20InputHandlerSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KCoreConfigSkeleton::qt_metacast(_clname);
}

int InputHandlerSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCoreConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void InputHandlerSettings::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InputHandlerSettings::gameControllerEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InputHandlerSettings::cecEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void InputHandlerSettings::autoSuppressInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InputHandlerSettings::disabledControllersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void InputHandlerSettings::startButtonDisabledWhenSuppressedControllersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
