// /qt/qml/org/kde/bigscreen/NavigationSoundEffects.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_bigscreen_NavigationSoundEffects_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0xb,0x0,0x0,0x67,0xba,0xec,0x1e,
0x39,0xb6,0x46,0x4d,0xc2,0x9f,0xf7,0xb0,
0x0,0x1,0xfc,0x28,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x80,0x4,0x0,0x0,
0x5,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x27,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x78,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x9,0x0,0x0,
0x80,0x1,0x0,0x0,0x50,0x2,0x0,0x0,
0x8,0x3,0x0,0x0,0xc0,0x3,0x0,0x0,
0x20,0x4,0x0,0x0,0x43,0x0,0x0,0x0,
0x30,0x1,0x0,0x0,0x40,0x1,0x0,0x0,
0x93,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0x50,0x1,0x0,0x0,0x93,0x0,0x0,0x0,
0x64,0x1,0x0,0x0,0xa3,0x0,0x0,0x0,
0xa3,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0xa3,0x0,0x0,0x0,0x64,0x1,0x0,0x0,
0x43,0x0,0x0,0x0,0x30,0x1,0x0,0x0,
0x40,0x1,0x0,0x0,0x93,0x0,0x0,0x0,
0xc3,0x0,0x0,0x0,0x73,0x0,0x0,0x0,
0x74,0x1,0x0,0x0,0x93,0x0,0x0,0x0,
0x84,0x1,0x0,0x0,0x43,0x0,0x0,0x0,
0x30,0x1,0x0,0x0,0x40,0x1,0x0,0x0,
0xa3,0x0,0x0,0x0,0xf3,0x0,0x0,0x0,
0x73,0x0,0x0,0x0,0x74,0x1,0x0,0x0,
0xa3,0x0,0x0,0x0,0x84,0x1,0x0,0x0,
0x93,0x1,0x0,0x0,0x93,0x1,0x0,0x0,
0xb0,0x1,0x0,0x0,0xa4,0x1,0x0,0x0,
0x93,0x1,0x0,0x0,0x93,0x1,0x0,0x0,
0xb0,0x1,0x0,0x0,0xa4,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8c,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1d,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x25,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x74,0x50,0x2,0xe,0x2,0x2e,
0x3,0x50,0xf,0x2e,0x4,0x3c,0x5,0x50,
0x9,0x2e,0x6,0x18,0x7,0xac,0x7,0x7,
0x0,0x0,0x2e,0x8,0x50,0xf,0x2e,0x9,
0x3c,0xa,0x50,0x9,0x2e,0xb,0x18,0x7,
0xac,0xc,0x7,0x0,0x0,0x16,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x2b,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x29,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2b,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x30,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2e,0xd,0x3c,0xe,0x3c,0xf,0x74,0x50,
0x2,0xe,0x2,0x2e,0x10,0x74,0x50,0xf,
0x2e,0x11,0x18,0x7,0x2e,0x12,0x18,0xa,
0xac,0x13,0x7,0x1,0xa,0x30,0x9,0x2e,
0x14,0x18,0x7,0xac,0x15,0x7,0x0,0x0,
0x16,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x2b,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x33,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x35,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x3a,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x3b,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2e,0x16,0x3c,0x17,0x3c,0x18,0x74,0x50,
0x2,0xe,0x2,0x2e,0x19,0x74,0x50,0xf,
0x2e,0x1a,0x18,0x7,0x2e,0x1b,0x18,0xa,
0xac,0x1c,0x7,0x1,0xa,0x30,0xa,0x2e,
0x1d,0x18,0x7,0xac,0x1e,0x7,0x0,0x0,
0x16,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1f,0x18,0x7,
0x2e,0x20,0x3c,0x21,0x18,0xa,0x12,0x1c,
0x18,0xb,0xac,0x22,0x7,0x2,0xa,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x23,0x18,0x7,
0x2e,0x24,0x3c,0x25,0x18,0xa,0x12,0x1d,
0x18,0xb,0xac,0x26,0x7,0x2,0xa,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0xf8,0x4,0x0,0x0,0x0,0x5,0x0,0x0,
0x18,0x5,0x0,0x0,0x38,0x5,0x0,0x0,
0x60,0x5,0x0,0x0,0x88,0x5,0x0,0x0,
0xc0,0x5,0x0,0x0,0xd8,0x5,0x0,0x0,
0x10,0x6,0x0,0x0,0x30,0x6,0x0,0x0,
0x50,0x6,0x0,0x0,0x70,0x6,0x0,0x0,
0x88,0x6,0x0,0x0,0xb8,0x6,0x0,0x0,
0xd0,0x6,0x0,0x0,0x0,0x7,0x0,0x0,
0x30,0x7,0x0,0x0,0x60,0x7,0x0,0x0,
0x88,0x7,0x0,0x0,0xb0,0x7,0x0,0x0,
0xc8,0x7,0x0,0x0,0x0,0x8,0x0,0x0,
0x18,0x8,0x0,0x0,0x28,0x8,0x0,0x0,
0x48,0x8,0x0,0x0,0x58,0x8,0x0,0x0,
0x78,0x8,0x0,0x0,0x90,0x8,0x0,0x0,
0xc0,0x8,0x0,0x0,0x10,0x9,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x4d,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,
0x69,0x0,0x6d,0x0,0x65,0x0,0x64,0x0,
0x69,0x0,0x61,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x2e,0x0,0x6c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x66,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x42,0x0,0x69,0x0,
0x67,0x0,0x73,0x0,0x63,0x0,0x72,0x0,
0x65,0x0,0x65,0x0,0x6e,0x0,0x53,0x0,
0x68,0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x62,0x0,0x69,0x0,
0x67,0x0,0x73,0x0,0x63,0x0,0x72,0x0,
0x65,0x0,0x65,0x0,0x6e,0x0,0x2e,0x0,
0x73,0x0,0x68,0x0,0x65,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x4f,0x0,0x62,0x0,0x6a,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x6e,0x0,0x61,0x0,
0x76,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x45,0x0,0x66,0x0,0x66,0x0,
0x65,0x0,0x63,0x0,0x74,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x53,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x45,0x0,
0x66,0x0,0x66,0x0,0x65,0x0,0x63,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x53,0x0,0x6f,0x0,0x75,0x0,
0x6e,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x76,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x63,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x53,0x0,0x6f,0x0,0x75,0x0,
0x6e,0x0,0x64,0x0,0x43,0x0,0x6f,0x0,
0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x76,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x43,0x0,0x6f,0x0,0x6d,0x0,
0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x6f,0x0,0x70,0x0,0x4e,0x0,0x61,0x0,
0x76,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x43,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x53,0x0,0x6f,0x0,0x75,0x0,
0x6e,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x4d,0x0,0x6f,0x0,
0x76,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x53,0x0,0x65,0x0,
0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x6e,0x0,0x61,0x0,
0x76,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,
0x64,0x0,0x45,0x0,0x6e,0x0,0x61,0x0,
0x62,0x0,0x6c,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x6f,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x63,0x0,0x72,0x0,
0x65,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x4f,0x0,0x62,0x0,0x6a,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x61,0x0,0x6e,0x0,0x64,0x0,0x61,0x0,
0x72,0x0,0x64,0x0,0x50,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x73,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6c,0x0,0x6f,0x0,
0x63,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x47,0x0,0x65,0x0,
0x6e,0x0,0x65,0x0,0x72,0x0,0x69,0x0,
0x63,0x0,0x44,0x0,0x61,0x0,0x74,0x0,
0x61,0x0,0x4c,0x0,0x6f,0x0,0x63,0x0,
0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x73,0x0,
0x2f,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x73,0x0,0x6d,0x0,0x61,0x0,0x2d,0x0,
0x62,0x0,0x69,0x0,0x67,0x0,0x73,0x0,
0x63,0x0,0x72,0x0,0x65,0x0,0x65,0x0,
0x6e,0x0,0x2f,0x0,0x63,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x6b,0x0,0x65,0x0,
0x64,0x0,0x2e,0x0,0x77,0x0,0x61,0x0,
0x76,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x73,0x0,
0x2f,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x73,0x0,0x6d,0x0,0x61,0x0,0x2d,0x0,
0x62,0x0,0x69,0x0,0x67,0x0,0x73,0x0,
0x63,0x0,0x72,0x0,0x65,0x0,0x65,0x0,
0x6e,0x0,0x2f,0x0,0x6d,0x0,0x6f,0x0,
0x76,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x2e,0x0,0x77,0x0,0x61,0x0,0x76,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0xb,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x6c,0x0,0x0,0x0,0x2c,0x1,0x0,0x0,
0x9c,0x1,0x0,0x0,0x6,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x3,0x0,0x4,0x0,
0x54,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x90,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x90,0x0,0x0,0x0,0x90,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x90,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0xf,0x0,0x10,0x0,0x10,0x0,0x50,0x0,
0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x12,0x0,0x50,0x0,
0xa,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0xc,0x0,0x0,0x0,
0xb,0x0,0x0,0x80,0x15,0x0,0x50,0x0,
0xf,0x0,0x0,0x0,0xb,0x0,0x0,0x80,
0x19,0x0,0x50,0x0,0xf,0x0,0x0,0x0,
0x8,0x0,0x8,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x10,0x2,
0x19,0x0,0x70,0x3,0xc,0x0,0x0,0x0,
0x8,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x10,0x2,
0x15,0x0,0x80,0x3,0x8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x15,0x0,0x80,0x3,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x16,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x19,0x0,0x70,0x3,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x1a,0x0,0x10,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// stopNavigationSounds at line 29, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_15, markStack);
    aotContext->mark(v2_2, markStack);
    aotContext->mark(v2_21, markStack);
    aotContext->mark(v2_25, markStack);
    aotContext->mark(v2_34, markStack);
    aotContext->mark(v2_40, markStack);
    aotContext->mark(v2_44, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_15 = nullptr;
QObject *v2_2 = nullptr;
QObject *v2_21 = nullptr;
QObject *v2_34 = nullptr;
QObject *v2_40 = nullptr;
QVariant v2_25;
QVariant v2_44;
bool v2_11;
bool v2_17;
bool v2_30;
bool v2_36;
bool v2_4;
bool v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->loadSingletonLookup(1, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initLoadSingletonLookup(1, 4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->getObjectLookup(2, s.v2_2, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initGetObjectLookupAsVariant(2, s.v2_2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_4 = aotContext->engine->fromVariant<bool>(std::move(retrieved));
}
{
}
// generate_UNot
s.v2_6 = !s.v2_4;
{
}
// generate_JumpFalse
if (!s.v2_6) {
    goto label_0;
}
{
}
{
}
// generate_Ret
return;
label_0:;
// generate_LoadQmlContextPropertyLookup
{
QObject * retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(3, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
aotContext->initLoadScopeObjectPropertyLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_11 = (std::move(retrieved) != nullptr);
}
{
}
// generate_JumpFalse
if (!s.v2_11) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(4, &s.v2_15)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
aotContext->initLoadScopeObjectPropertyLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
while (!aotContext->getObjectLookup(5, s.v2_15, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
aotContext->initGetObjectLookupAsVariant(5, s.v2_15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_17 = aotContext->engine->fromVariant<bool>(std::move(retrieved));
}
{
}
// generate_JumpFalse
if (!s.v2_17) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(6, &s.v2_21)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
aotContext->initLoadScopeObjectPropertyLookup(6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(7, s.v2_21, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(7, s.v2_21);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_25 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_25);
}
{
}
label_1:;
// generate_LoadQmlContextPropertyLookup
{
QObject * retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(8, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
aotContext->initLoadScopeObjectPropertyLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_30 = (std::move(retrieved) != nullptr);
}
{
}
// generate_JumpFalse
if (!s.v2_30) {
    goto label_2;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(9, &s.v2_34)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
aotContext->initLoadScopeObjectPropertyLookup(9);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->getObjectLookup(10, s.v2_34, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initGetObjectLookupAsVariant(10, s.v2_34);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_36 = aotContext->engine->fromVariant<bool>(std::move(retrieved));
}
{
}
// generate_JumpFalse
if (!s.v2_36) {
    goto label_2;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(11, &s.v2_40)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
aotContext->initLoadScopeObjectPropertyLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(12, s.v2_40, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(12, s.v2_40);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(49);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(49);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_44 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_44);
}
{
}
label_2:;
{
}
// generate_Ret
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 22, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_10;
QUrl v2_14;
int v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(31, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(31, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getEnumLookup(33, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetEnumLookup(33, []() { static const auto t = QMetaType::fromName("QStandardPaths"); return t; }().metaObject(), "StandardLocation", "GenericDataLocation");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_10 = QStringLiteral("sounds/plasma-bigscreen/clicked.wav");
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QUrl callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_6, &s.v2_10};
    return aotContext->callObjectPropertyLookup(34, s.v2_0, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(34, s.v2_0, 4);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_14 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_14);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_14);
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 26, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_10;
QUrl v2_14;
int v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(35, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(35, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getEnumLookup(37, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetEnumLookup(37, []() { static const auto t = QMetaType::fromName("QStandardPaths"); return t; }().metaObject(), "StandardLocation", "GenericDataLocation");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_10 = QStringLiteral("sounds/plasma-bigscreen/moving.wav");
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QUrl callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_6, &s.v2_10};
    return aotContext->callObjectPropertyLookup(38, s.v2_0, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(38, s.v2_0, 4);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_14 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_14);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = std::move(s.v2_14);
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
