/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasma.bigscreen.inputhandler.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef INPUTHANDLERINTERFACE_H
#define INPUTHANDLERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.plasma.bigscreen.inputhandler
 */
class OrgKdePlasmaBigscreenInputhandlerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.plasma.bigscreen.inputhandler"; }

public:
    OrgKdePlasmaBigscreenInputhandlerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdePlasmaBigscreenInputhandlerInterface();

    Q_PROPERTY(bool autoSuppressInput READ autoSuppressInput WRITE setAutoSuppressInput)
    inline bool autoSuppressInput() const
    { return qvariant_cast< bool >(property("autoSuppressInput")); }
    inline void setAutoSuppressInput(bool value)
    { setProperty("autoSuppressInput", QVariant::fromValue(value)); }

    Q_PROPERTY(bool cecEnabled READ cecEnabled WRITE setCecEnabled)
    inline bool cecEnabled() const
    { return qvariant_cast< bool >(property("cecEnabled")); }
    inline void setCecEnabled(bool value)
    { setProperty("cecEnabled", QVariant::fromValue(value)); }

    Q_PROPERTY(bool enabled READ enabled WRITE setEnabled)
    inline bool enabled() const
    { return qvariant_cast< bool >(property("enabled")); }
    inline void setEnabled(bool value)
    { setProperty("enabled", QVariant::fromValue(value)); }

    Q_PROPERTY(bool gameControllerEnabled READ gameControllerEnabled WRITE setGameControllerEnabled)
    inline bool gameControllerEnabled() const
    { return qvariant_cast< bool >(property("gameControllerEnabled")); }
    inline void setGameControllerEnabled(bool value)
    { setProperty("gameControllerEnabled", QVariant::fromValue(value)); }

    Q_PROPERTY(bool inputManuallySuppressed READ inputManuallySuppressed)
    inline bool inputManuallySuppressed() const
    { return qvariant_cast< bool >(property("inputManuallySuppressed")); }

    Q_PROPERTY(bool inputSuppressed READ inputSuppressed WRITE setInputSuppressed)
    inline bool inputSuppressed() const
    { return qvariant_cast< bool >(property("inputSuppressed")); }
    inline void setInputSuppressed(bool value)
    { setProperty("inputSuppressed", QVariant::fromValue(value)); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QVariantList> connectedControllers()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("connectedControllers"), argumentList);
    }

    inline QDBusPendingReply<bool> isCecControllerConnected()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isCecControllerConnected"), argumentList);
    }

    inline QDBusPendingReply<bool> isSdlControllerConnected()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("isSdlControllerConnected"), argumentList);
    }

    inline QDBusPendingReply<int> queryDevicePowerStatus(int logicalAddress)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(logicalAddress);
        return asyncCallWithArgumentList(QStringLiteral("queryDevicePowerStatus"), argumentList);
    }

    inline QDBusPendingReply<bool> sendActiveSource()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("sendActiveSource"), argumentList);
    }

    inline QDBusPendingReply<bool> sendImageViewOn(int logicalAddress)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(logicalAddress);
        return asyncCallWithArgumentList(QStringLiteral("sendImageViewOn"), argumentList);
    }

    inline QDBusPendingReply<bool> sendStandby(int logicalAddress)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(logicalAddress);
        return asyncCallWithArgumentList(QStringLiteral("sendStandby"), argumentList);
    }

    inline QDBusPendingReply<> setControllerEnabled(const QString &uniqueIdentifier, bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uniqueIdentifier) << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("setControllerEnabled"), argumentList);
    }

    inline QDBusPendingReply<> setStartButtonEnabledWhenSuppressed(const QString &uniqueIdentifier, bool enabled)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uniqueIdentifier) << QVariant::fromValue(enabled);
        return asyncCallWithArgumentList(QStringLiteral("setStartButtonEnabledWhenSuppressed"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void autoSuppressInputChanged(bool enabled);
    void cecControllerAdded(const QString &name);
    void cecControllerRemoved(const QString &name);
    void cecEnabledChanged(bool enabled);
    void connectedControllersChanged();
    void enabledChanged(bool enabled);
    void gameControllerEnabledChanged(bool enabled);
    void homeActionRequested();
    void inputSuppressedChanged(bool suppressed, bool automatic);
    void sdlControllerAdded(const QString &name);
    void sdlControllerRemoved(const QString &name);
};

namespace org {
  namespace kde {
    namespace plasma {
      namespace bigscreen {
        using inputhandler = ::OrgKdePlasmaBigscreenInputhandlerInterface;
      }
    }
  }
}

#endif
