/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.biglauncher.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "biglauncheradaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class BiglauncherAdaptor
 */

BiglauncherAdaptor::BiglauncherAdaptor(BigLauncherDbusAdapterInterface *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

BiglauncherAdaptor::~BiglauncherAdaptor()
{
    // destructor
}

QString BiglauncherAdaptor::activateSettingsShortcut()
{
    // handle method call org.kde.biglauncher.activateSettingsShortcut
    return parent()->activateSettingsShortcut();
}

QString BiglauncherAdaptor::activateTasksShortcut()
{
    // handle method call org.kde.biglauncher.activateTasksShortcut
    return parent()->activateTasksShortcut();
}

void BiglauncherAdaptor::activateWallpaperSelector()
{
    // handle method call org.kde.biglauncher.activateWallpaperSelector
    parent()->activateWallpaperSelector();
}

bool BiglauncherAdaptor::coloredTilesActive()
{
    // handle method call org.kde.biglauncher.coloredTilesActive
    return parent()->coloredTilesActive();
}

QString BiglauncherAdaptor::displayHomeOverlayShortcut()
{
    // handle method call org.kde.biglauncher.displayHomeOverlayShortcut
    return parent()->displayHomeOverlayShortcut();
}

QString BiglauncherAdaptor::displayHomeScreenShortcut()
{
    // handle method call org.kde.biglauncher.displayHomeScreenShortcut
    return parent()->displayHomeScreenShortcut();
}

void BiglauncherAdaptor::resetActivateSettingsShortcut()
{
    // handle method call org.kde.biglauncher.resetActivateSettingsShortcut
    parent()->resetActivateSettingsShortcut();
}

void BiglauncherAdaptor::resetActivateTasksShortcut()
{
    // handle method call org.kde.biglauncher.resetActivateTasksShortcut
    parent()->resetActivateTasksShortcut();
}

void BiglauncherAdaptor::resetDisplayHomeOverlayShortcut()
{
    // handle method call org.kde.biglauncher.resetDisplayHomeOverlayShortcut
    parent()->resetDisplayHomeOverlayShortcut();
}

void BiglauncherAdaptor::resetDisplayHomeScreenShortcut()
{
    // handle method call org.kde.biglauncher.resetDisplayHomeScreenShortcut
    parent()->resetDisplayHomeScreenShortcut();
}

bool BiglauncherAdaptor::setActivateSettingsShortcut(const QString &shortcut)
{
    // handle method call org.kde.biglauncher.setActivateSettingsShortcut
    return parent()->setActivateSettingsShortcut(shortcut);
}

bool BiglauncherAdaptor::setActivateTasksShortcut(const QString &shortcut)
{
    // handle method call org.kde.biglauncher.setActivateTasksShortcut
    return parent()->setActivateTasksShortcut(shortcut);
}

bool BiglauncherAdaptor::setDisplayHomeOverlayShortcut(const QString &shortcut)
{
    // handle method call org.kde.biglauncher.setDisplayHomeOverlayShortcut
    return parent()->setDisplayHomeOverlayShortcut(shortcut);
}

bool BiglauncherAdaptor::setDisplayHomeScreenShortcut(const QString &shortcut)
{
    // handle method call org.kde.biglauncher.setDisplayHomeScreenShortcut
    return parent()->setDisplayHomeScreenShortcut(shortcut);
}

void BiglauncherAdaptor::useColoredTiles(bool coloredTiles)
{
    // handle method call org.kde.biglauncher.useColoredTiles
    parent()->useColoredTiles(coloredTiles);
}

void BiglauncherAdaptor::useWallpaperBlur(bool wallpaperBlur)
{
    // handle method call org.kde.biglauncher.useWallpaperBlur
    parent()->useWallpaperBlur(wallpaperBlur);
}

bool BiglauncherAdaptor::wallpaperBlurActive()
{
    // handle method call org.kde.biglauncher.wallpaperBlurActive
    return parent()->wallpaperBlurActive();
}


#include "moc_biglauncheradaptor.cpp"
