/****************************************************************************
** Meta object code from reading C++ file 'displaymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-bigscreen-6.7.4/kcms/display/displaymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displaymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12DisplayModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DisplayModel::qt_create_metaobjectdata<qt_meta_tag_ZN12DisplayModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisplayModel",
        "countChanged",
        "",
        "displayConfigurationChanged",
        "displayScaleChanged",
        "selectedDisplayChanged",
        "syncDisplayOptions",
        "selectedDisplayId",
        "selectedDisplayName",
        "selectedDisplayEnabled",
        "selectedDisplayScale",
        "selectedDisplayAvailableModes",
        "selectedDisplayMode",
        "DisplayRoles",
        "IdRole",
        "OutputNameRole",
        "EnabledRole",
        "OutputRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayConfigurationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayScaleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedDisplayChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'syncDisplayOptions'
        QtMocHelpers::MethodData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selectedDisplayId'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'selectedDisplayName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'selectedDisplayEnabled'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'selectedDisplayScale'
        QtMocHelpers::PropertyData<double>(10, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'selectedDisplayAvailableModes'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'selectedDisplayMode'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DisplayRoles'
        QtMocHelpers::EnumData<enum DisplayRoles>(13, 13, QMC::EnumFlags{}).add({
            {   14, DisplayRoles::IdRole },
            {   15, DisplayRoles::OutputNameRole },
            {   16, DisplayRoles::EnabledRole },
            {   17, DisplayRoles::OutputRole },
        }),
    };
    return QtMocHelpers::metaObjectData<DisplayModel, qt_meta_tag_ZN12DisplayModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DisplayModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DisplayModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DisplayModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12DisplayModelE_t>.metaTypes,
    nullptr
} };

void DisplayModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->displayConfigurationChanged(); break;
        case 2: _t->displayScaleChanged(); break;
        case 3: _t->selectedDisplayChanged(); break;
        case 4: _t->syncDisplayOptions(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)()>(_a, &DisplayModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)()>(_a, &DisplayModel::displayConfigurationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)()>(_a, &DisplayModel::displayScaleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisplayModel::*)()>(_a, &DisplayModel::selectedDisplayChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->selectedDisplayId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->selectedDisplayName(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->selectedDisplayEnabled(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->selectedDisplayScale(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->selectedDisplayAvailableModes(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->selectedDisplayMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSelectedDisplayId(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectedDisplayEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setSelectedDisplayScale(*reinterpret_cast<double*>(_v)); break;
        case 5: _t->setSelectedDisplayMode(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DisplayModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisplayModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DisplayModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int DisplayModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DisplayModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DisplayModel::displayConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DisplayModel::displayScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DisplayModel::selectedDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
