/****************************************************************************
** Meta object code from reading C++ file 'biglauncher_dbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-bigscreen-6.7.4/containments/homescreen/plugin/biglauncher_dbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'biglauncher_dbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto BigLauncherDbusAdapterInterface::qt_create_metaobjectdata<qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BigLauncherDbusAdapterInterface",
        "D-Bus Interface",
        "org.kde.biglauncher",
        "useColoredTilesChanged",
        "",
        "msgUseColoredTiles",
        "useWallpaperBlurChanged",
        "msgUseWallpaperBlur",
        "activateWallpaperSelectorRequested",
        "useColoredTiles",
        "coloredTiles",
        "coloredTilesActive",
        "useWallpaperBlur",
        "wallpaperBlur",
        "wallpaperBlurActive",
        "activateWallpaperSelector",
        "activateSettingsShortcut",
        "activateTasksShortcut",
        "displayHomeScreenShortcut",
        "displayHomeOverlayShortcut",
        "setActivateSettingsShortcut",
        "shortcut",
        "setActivateTasksShortcut",
        "setDisplayHomeScreenShortcut",
        "setDisplayHomeOverlayShortcut",
        "resetActivateSettingsShortcut",
        "resetActivateTasksShortcut",
        "resetDisplayHomeScreenShortcut",
        "resetDisplayHomeOverlayShortcut",
        "getMethod",
        "method"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'useColoredTilesChanged'
        QtMocHelpers::SignalData<void(const bool &)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'useWallpaperBlurChanged'
        QtMocHelpers::SignalData<void(const bool &)>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'activateWallpaperSelectorRequested'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'useColoredTiles'
        QtMocHelpers::SlotData<void(const bool &)>(9, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'coloredTilesActive'
        QtMocHelpers::SlotData<bool()>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'useWallpaperBlur'
        QtMocHelpers::SlotData<void(const bool &)>(12, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'wallpaperBlurActive'
        QtMocHelpers::SlotData<bool()>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Slot 'activateWallpaperSelector'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'activateSettingsShortcut'
        QtMocHelpers::SlotData<QString()>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'activateTasksShortcut'
        QtMocHelpers::SlotData<QString()>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'displayHomeScreenShortcut'
        QtMocHelpers::SlotData<QString()>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'displayHomeOverlayShortcut'
        QtMocHelpers::SlotData<QString()>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'setActivateSettingsShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setActivateTasksShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<bool(const QString &)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'resetActivateSettingsShortcut'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'resetActivateTasksShortcut'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'resetDisplayHomeScreenShortcut'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'resetDisplayHomeOverlayShortcut'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'getMethod'
        QtMocHelpers::MethodData<QString(const QString &)>(29, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BigLauncherDbusAdapterInterface, qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BigLauncherDbusAdapterInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>.metaTypes,
    nullptr
} };

void BigLauncherDbusAdapterInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BigLauncherDbusAdapterInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->useColoredTilesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->useWallpaperBlurChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->activateWallpaperSelectorRequested(); break;
        case 3: _t->useColoredTiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: { bool _r = _t->coloredTilesActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->useWallpaperBlur((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: { bool _r = _t->wallpaperBlurActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->activateWallpaperSelector(); break;
        case 8: { QString _r = _t->activateSettingsShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->activateTasksShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->displayHomeScreenShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->displayHomeOverlayShortcut();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setActivateSettingsShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->setActivateTasksShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->setDisplayHomeScreenShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->setDisplayHomeOverlayShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->resetActivateSettingsShortcut(); break;
        case 17: _t->resetActivateTasksShortcut(); break;
        case 18: _t->resetDisplayHomeScreenShortcut(); break;
        case 19: _t->resetDisplayHomeOverlayShortcut(); break;
        case 20: { QString _r = _t->getMethod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BigLauncherDbusAdapterInterface::*)(const bool & )>(_a, &BigLauncherDbusAdapterInterface::useColoredTilesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigLauncherDbusAdapterInterface::*)(const bool & )>(_a, &BigLauncherDbusAdapterInterface::useWallpaperBlurChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BigLauncherDbusAdapterInterface::*)()>(_a, &BigLauncherDbusAdapterInterface::activateWallpaperSelectorRequested, 2))
            return;
    }
}

const QMetaObject *BigLauncherDbusAdapterInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BigLauncherDbusAdapterInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN31BigLauncherDbusAdapterInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BigLauncherDbusAdapterInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void BigLauncherDbusAdapterInterface::useColoredTilesChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BigLauncherDbusAdapterInterface::useWallpaperBlurChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BigLauncherDbusAdapterInterface::activateWallpaperSelectorRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
