/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.plasma.bigscreen.inputhandler.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef INPUTHANDLERADAPTOR_H
#define INPUTHANDLERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "inputhandlerdbus.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.plasma.bigscreen.inputhandler
 */
class InputhandlerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma.bigscreen.inputhandler")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.plasma.bigscreen.inputhandler\">\n"
"    <property access=\"readwrite\" type=\"b\" name=\"inputSuppressed\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"inputManuallySuppressed\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"autoSuppressInput\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"enabled\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"gameControllerEnabled\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"cecEnabled\"/>\n"
"    <signal name=\"sdlControllerAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"sdlControllerRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"cecControllerAdded\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"cecControllerRemoved\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"name\"/>\n"
"    </signal>\n"
"    <signal name=\"inputSuppressedChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"suppressed\"/>\n"
"      <arg direction=\"out\" type=\"b\" name=\"automatic\"/>\n"
"    </signal>\n"
"    <signal name=\"autoSuppressInputChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <signal name=\"homeActionRequested\"/>\n"
"    <signal name=\"enabledChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <signal name=\"gameControllerEnabledChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <signal name=\"cecEnabledChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"enabled\"/>\n"
"    </signal>\n"
"    <signal name=\"connectedControllersChanged\"/>\n"
"    <method name=\"isSdlControllerConnected\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"isCecControllerConnected\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"connectedControllers\">\n"
"      <arg direction=\"out\" type=\"av\"/>\n"
"    </method>\n"
"    <method name=\"setControllerEnabled\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uniqueIdentifier\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"    </method>\n"
"    <method name=\"setStartButtonEnabledWhenSuppressed\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"uniqueIdentifier\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"    </method>\n"
"    <method name=\"sendStandby\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"logicalAddress\"/>\n"
"    </method>\n"
"    <method name=\"sendImageViewOn\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"logicalAddress\"/>\n"
"    </method>\n"
"    <method name=\"sendActiveSource\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"queryDevicePowerStatus\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"logicalAddress\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    InputhandlerAdaptor(InputHandlerDBus *parent);
    ~InputhandlerAdaptor() override;

    inline InputHandlerDBus *parent() const
    { return static_cast<InputHandlerDBus *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool autoSuppressInput READ autoSuppressInput WRITE setAutoSuppressInput)
    bool autoSuppressInput() const;
    void setAutoSuppressInput(bool value);

    Q_PROPERTY(bool cecEnabled READ cecEnabled WRITE setCecEnabled)
    bool cecEnabled() const;
    void setCecEnabled(bool value);

    Q_PROPERTY(bool enabled READ enabled WRITE setEnabled)
    bool enabled() const;
    void setEnabled(bool value);

    Q_PROPERTY(bool gameControllerEnabled READ gameControllerEnabled WRITE setGameControllerEnabled)
    bool gameControllerEnabled() const;
    void setGameControllerEnabled(bool value);

    Q_PROPERTY(bool inputManuallySuppressed READ inputManuallySuppressed)
    bool inputManuallySuppressed() const;

    Q_PROPERTY(bool inputSuppressed READ inputSuppressed WRITE setInputSuppressed)
    bool inputSuppressed() const;
    void setInputSuppressed(bool value);

public Q_SLOTS: // METHODS
    QVariantList connectedControllers();
    bool isCecControllerConnected();
    bool isSdlControllerConnected();
    int queryDevicePowerStatus(int logicalAddress);
    bool sendActiveSource();
    bool sendImageViewOn(int logicalAddress);
    bool sendStandby(int logicalAddress);
    void setControllerEnabled(const QString &uniqueIdentifier, bool enabled);
    void setStartButtonEnabledWhenSuppressed(const QString &uniqueIdentifier, bool enabled);
Q_SIGNALS: // SIGNALS
    void autoSuppressInputChanged(bool enabled);
    void cecControllerAdded(const QString &name);
    void cecControllerRemoved(const QString &name);
    void cecEnabledChanged(bool enabled);
    void connectedControllersChanged();
    void enabledChanged(bool enabled);
    void gameControllerEnabledChanged(bool enabled);
    void homeActionRequested();
    void inputSuppressedChanged(bool suppressed, bool automatic);
    void sdlControllerAdded(const QString &name);
    void sdlControllerRemoved(const QString &name);
};

#endif
