/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.biglauncher.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef BIGLAUNCHERADAPTOR_H
#define BIGLAUNCHERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "/build/plasma-bigscreen/src/plasma-bigscreen-6.7.4/containments/homescreen/plugin/biglauncher_dbus.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.biglauncher
 */
class BiglauncherAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.biglauncher")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.biglauncher\">\n"
"    <signal name=\"useColoredTilesChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"msgUseColoredTiles\"/>\n"
"    </signal>\n"
"    <signal name=\"useWallpaperBlurChanged\">\n"
"      <arg direction=\"out\" type=\"b\" name=\"msgUseWallpaperBlur\"/>\n"
"    </signal>\n"
"    <method name=\"useColoredTiles\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"coloredTiles\"/>\n"
"    </method>\n"
"    <method name=\"coloredTilesActive\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"useWallpaperBlur\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"wallpaperBlur\"/>\n"
"    </method>\n"
"    <method name=\"wallpaperBlurActive\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"activateWallpaperSelector\"/>\n"
"    <method name=\"activateSettingsShortcut\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"activateTasksShortcut\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"displayHomeScreenShortcut\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"displayHomeOverlayShortcut\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setActivateSettingsShortcut\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"    </method>\n"
"    <method name=\"setActivateTasksShortcut\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"    </method>\n"
"    <method name=\"setDisplayHomeScreenShortcut\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"    </method>\n"
"    <method name=\"setDisplayHomeOverlayShortcut\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"shortcut\"/>\n"
"    </method>\n"
"    <method name=\"resetActivateSettingsShortcut\"/>\n"
"    <method name=\"resetActivateTasksShortcut\"/>\n"
"    <method name=\"resetDisplayHomeScreenShortcut\"/>\n"
"    <method name=\"resetDisplayHomeOverlayShortcut\"/>\n"
"  </interface>\n"
        "")
public:
    BiglauncherAdaptor(BigLauncherDbusAdapterInterface *parent);
    ~BiglauncherAdaptor() override;

    inline BigLauncherDbusAdapterInterface *parent() const
    { return static_cast<BigLauncherDbusAdapterInterface *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    QString activateSettingsShortcut();
    QString activateTasksShortcut();
    void activateWallpaperSelector();
    bool coloredTilesActive();
    QString displayHomeOverlayShortcut();
    QString displayHomeScreenShortcut();
    void resetActivateSettingsShortcut();
    void resetActivateTasksShortcut();
    void resetDisplayHomeOverlayShortcut();
    void resetDisplayHomeScreenShortcut();
    bool setActivateSettingsShortcut(const QString &shortcut);
    bool setActivateTasksShortcut(const QString &shortcut);
    bool setDisplayHomeOverlayShortcut(const QString &shortcut);
    bool setDisplayHomeScreenShortcut(const QString &shortcut);
    void useColoredTiles(bool coloredTiles);
    void useWallpaperBlur(bool wallpaperBlur);
    bool wallpaperBlurActive();
Q_SIGNALS: // SIGNALS
    void useColoredTilesChanged(bool msgUseColoredTiles);
    void useWallpaperBlurChanged(bool msgUseWallpaperBlur);
};

#endif
